@@ -7,7 +7,10 @@ import ntpath
 from .colors import *
 from . import log
 
-logger = log.gen("FLAUNCHER")
+if __name__ == "__main__":
+    logger = log.gen(mode="dev")
+else:
+    logger = log.gen()
 
 __author__ = 'Yann Orieult'
 
@@ -360,3 +363,7 @@ def launch():
 
     for f_type, f_paths in f_paths_by_exts.items():
         _run_cmds(f_paths_by_exts, f_type, conf, conf_path)
+
+
+if __name__ == "__main__":
+    launch()
